/** -*- mode: c++ ; c-basic-offset: 2 -*-
 *
 *  @file LayersExtentProxy.h
 *
 *  Copyright 2017 Sebastien Fourey
 *
 *  This file is part of G'MIC-Qt, a generic plug-in for raster graphics
 *  editors, offering hundreds of filters thanks to the underlying G'MIC
 *  image processing framework.
 *
 *  gmic_qt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  gmic_qt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef GMIC_QT_LAYERS_EXTENT_PROXY_H
#define GMIC_QT_LAYERS_EXTENT_PROXY_H
#include <QSize>
#include "gmic_qt.h"

class LayersExtentProxy {
public:
  static void getExtent(GmicQt::InputMode mode, int & width, int & height);
  static QSize getExtent(GmicQt::InputMode mode);
  static void clear();

private:
  LayersExtentProxy() = delete;
  static int _width;
  static int _height;
  static GmicQt::InputMode _inputMode;
};

#endif // GMIC_QT_LAYERS_EXTENT_PROXY_H
